==> apache-ignite-2.8.0-src.zip: apache-ignite-2.8.0-src/modules/core/src/main/java/org/apache/ignite/internal/processors/platform/client/cluster/ClientClusterWalChangeStateRequest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.ignite.internal.processors.platform.client.cluster;

import org.apache.ignite.IgniteCluster;
import org.apache.ignite.binary.BinaryRawReader;
import org.apache.ignite.internal.processors.platform.client.ClientConnectionContext;
import org.apache.ignite.internal.processors.platform.client.ClientRequest;
import org.apache.ignite.internal.processors.platform.client.ClientResponse;

/**
 * Change cache WAL state request.
 */
public class ClientClusterWalChangeStateRequest extends ClientRequest {
    /** Cache name. */
    private final String cacheName;

    /** Next state. */
    private final boolean shouldBeActive;

    /**
     * Constructor.
     *
     * @param reader Reader.
     */
    public ClientClusterWalChangeStateRequest(BinaryRawReader reader) {
        super(reader);
        cacheName = reader.readString();
        shouldBeActive = reader.readBoolean();
    }

    /** {@inheritDoc} */
    @Override public ClientResponse process(ClientConnectionContext ctx) {
        IgniteCluster cluster = ctx.kernalContext().grid().cluster();
        boolean res = shouldBeActive
            ? cluster.enableWal(cacheName)
            : cluster.disableWal(cacheName);
        return new ClientClusterWalChangeStateResponse(requestId(), res);
    }
}

==> apache-ignite-2.17.0-src.zip: apache-ignite-2.17.0-src/modules/core/src/main/java/org/apache/ignite/internal/processors/platform/client/cluster/ClientClusterWalChangeStateRequest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.ignite.internal.processors.platform.client.cluster;

import org.apache.ignite.IgniteCluster;
import org.apache.ignite.binary.BinaryRawReader;
import org.apache.ignite.internal.processors.platform.client.ClientBooleanResponse;
import org.apache.ignite.internal.processors.platform.client.ClientConnectionContext;
import org.apache.ignite.internal.processors.platform.client.ClientRequest;
import org.apache.ignite.internal.processors.platform.client.ClientResponse;

/**
 * Change cache WAL state request.
 */
public class ClientClusterWalChangeStateRequest extends ClientRequest {
    /** Cache name. */
    private final String cacheName;

    /** Next state. */
    private final boolean shouldBeActive;

    /**
     * Constructor.
     *
     * @param reader Reader.
     */
    public ClientClusterWalChangeStateRequest(BinaryRawReader reader) {
        super(reader);
        cacheName = reader.readString();
        shouldBeActive = reader.readBoolean();
    }

    /** {@inheritDoc} */
    @Override public ClientResponse process(ClientConnectionContext ctx) {
        IgniteCluster cluster = ctx.kernalContext().grid().cluster();

        boolean res = shouldBeActive ? cluster.enableWal(cacheName) : cluster.disableWal(cacheName);

        return new ClientBooleanResponse(requestId(), res);
    }
}
